{% extends "errors/_base.html" %}

{% block error %}
    <p>
        Si è verificato un errore durante il login con Google tramite OpenID Connect.
    </p>
    <p>
        Ripeti la procedura di collegamento da capo: potresti aver accidentalmente alterato l'URL della pagina!
    </p>
{% endblock %}