{% extends "errors/_base.html" %}

{% block error %}
    <p>
        Si è verificato un errore nel recupero delle informazioni del tuo account Matrix da collegare.
    </p>
    <p>
        Per effettuare la procedura di login, è necessario il salvataggio di un cookie funzionale effimero che il tuo browser aver rifiutato o bloccato.
    </p>
    <p>
        Assicurati che il tuo browser sia configurato per accettare quel cookie, poi riprova!
    </p>
{% endblock %}