{% extends "errors/_base.html" %}

{% block error %}
    <p>
        Non è stato possibile inviarti un invito allo spazio <i>Unimore Studenti</i>.
    </p>
    <p>
        Il bot ha raggiunto il limite massimo di inviti inviabili in un dato arco di tempo.
    </p>
    <p>
        Potrebbero esserci molti utenti che stanno usando il bot in questo momento: aspetta qualche minuto, poi riprova!
    </p>
{% endblock %}