{% extends "errors/_base.html" %}

{% block error %}
    <p>
        La pagina che hai richiesto non esiste.
    </p>
    <p>
        Se sei uscito e poi rientrato dallo spazio <i>Unimore</i>, il link al tuo profilo <b>è cambiato</b>: assicurati di aver cliccato sull'ultimo link che ti ha inviato il bot!
    </p>
{% endblock %}